RichLineInfo

Struct RichLineInfo 

#[non_exhaustive]
pub struct RichLineInfo { pub starts_new_line: bool, pub is_wrap_start: bool, pub ends_in_new_line: bool, }
Info about how a rich text leaf defines new lines in a rich text.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
starts_new_line: bool

Leaf widget first line height span does not intersect the previous sibling last line height span vertically.

This heuristic allow multiple baselines in the same row (sub/superscript), it also allows bidi mixed segments that maybe have negative horizontal offsets, but very custom layouts such as a diagonal stack panel may want to provide their own definition of a line as an alternative to this API.

Note that this can be true due to wrap layout, usually this is ignored when defining a line for selection. Check is_wrap_start to implement real lines.

is_wrap_start: bool

if starts_new_line is true because the parent widget wrapped the leaf widget.

ends_in_new_line: bool

Leaf widget inline layout declared multiple lines so the end is in a new line.

Note that the widget may define multiple other lines inside itself, those don’t count as “rich text lines”.