pub struct FontFeaturesMix<P>(/* private fields */);Expand description
m Advanced font config, features, kerning, variations and more.
All properties in this mixin affects Text! nodes inside the widget where they are set.
Implementations
Sourceimpl FontFeaturesMix<()>
impl FontFeaturesMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_variations(&self, variations: impl IntoVar<FontVariations>)
pub fn font_variations(&self, variations: impl IntoVar<FontVariations>)
P Sets font variations.
Note: This property fully replaces the font variations for the widget and descendants, use with_font_variation
to create a property that sets a variation but retains others from the context.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_features(&self, features: impl IntoVar<FontFeatures>)
pub fn font_features(&self, features: impl IntoVar<FontFeatures>)
P Sets font features.
Note: This property fully replaces the font variations for the widget and descendants, use with_font_variation
to create a property that sets a variation but retains others from the context.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_kerning(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_kerning(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font kerning feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_common_lig(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_common_lig(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font common ligatures features.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_discretionary_lig(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_discretionary_lig(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font discretionary ligatures feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_historical_lig(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_historical_lig(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font historical ligatures feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_contextual_alt(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_contextual_alt(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font contextual alternatives feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_caps(&self, state: impl IntoVar<CapsVariant>)
pub fn font_caps(&self, state: impl IntoVar<CapsVariant>)
P Sets the font capital variant features.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_numeric(&self, state: impl IntoVar<NumVariant>)
pub fn font_numeric(&self, state: impl IntoVar<NumVariant>)
P Sets the font numeric variant features.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_num_spacing(&self, state: impl IntoVar<NumSpacing>)
pub fn font_num_spacing(&self, state: impl IntoVar<NumSpacing>)
P Sets the font numeric spacing features.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_num_fraction(&self, state: impl IntoVar<NumFraction>)
pub fn font_num_fraction(&self, state: impl IntoVar<NumFraction>)
P Sets the font numeric fraction features.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_swash(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_swash(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font swash features.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_stylistic(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_stylistic(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font stylistic alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_historical_forms(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_historical_forms(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font historical forms alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_ornaments(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_ornaments(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font ornaments alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_annotation(&self, state: impl IntoVar<FontFeatureState>)
pub fn font_annotation(&self, state: impl IntoVar<FontFeatureState>)
P Sets the font annotation alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_style_set(&self, state: impl IntoVar<FontStyleSet>)
pub fn font_style_set(&self, state: impl IntoVar<FontStyleSet>)
P Sets the font stylistic set alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_char_variant(&self, state: impl IntoVar<CharVariant>)
pub fn font_char_variant(&self, state: impl IntoVar<CharVariant>)
P Sets the font character variant alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_position(&self, state: impl IntoVar<FontPosition>)
pub fn font_position(&self, state: impl IntoVar<FontPosition>)
P Sets the font sub/super script position alternative feature.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_jp_variant(&self, state: impl IntoVar<JpVariant>)
pub fn font_jp_variant(&self, state: impl IntoVar<JpVariant>)
P Sets the Japanese logographic set.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_cn_variant(&self, state: impl IntoVar<CnVariant>)
pub fn font_cn_variant(&self, state: impl IntoVar<CnVariant>)
P Sets the Chinese logographic set.
Sourceimpl<P: WidgetImpl> FontFeaturesMix<P>
impl<P: WidgetImpl> FontFeaturesMix<P>
Sourcepub fn font_ea_width(&self, state: impl IntoVar<EastAsianWidth>)
pub fn font_ea_width(&self, state: impl IntoVar<EastAsianWidth>)
P Sets the East Asian figure width.