pub struct RichTextMix<P>(/* private fields */);Expand description
m Rich text properties.
Note that these properties are usually set in parent panels of text widgets.
Implementations
Sourceimpl RichTextMix<()>
impl RichTextMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.
Sourceimpl<P: WidgetImpl> RichTextMix<P>
impl<P: WidgetImpl> RichTextMix<P>
Sourcepub fn rich_text(&self, enabled: impl IntoVar<bool>)
pub fn rich_text(&self, enabled: impl IntoVar<bool>)
B Defines a rich text context.
When enabled text widget descendants of this widget edit the text across the widgets, for example, the caret position moves to the next text widget when it reaches the start/end of the first text widget.
Nested rich text contexts are allowed and are all part of the outermost context, enabling this property in all nested wrap panels is recommended as it enables some rich text behavior like bringing the focused widget to front to avoid clipping the caret.
When enabled and not nested the widget will handle text commands, it also broadcasts focus change events to all text descendants.
Sourceimpl<P: WidgetImpl> RichTextMix<P>
impl<P: WidgetImpl> RichTextMix<P>
Sourcepub fn rich_text_focused_z(&self, z_index: impl IntoVar<Option<ZIndex>>)
pub fn rich_text_focused_z(&self, z_index: impl IntoVar<Option<ZIndex>>)
P Defines the Z-index set on inner text (and nested rich text) widgets when focus is within.
Is ZIndex::FRONT by default, so that the caret visual is not clipped when the insert point is at
an edge between texts. Set to None to not change the Z-index on focus.
Sets the RICH_TEXT_FOCUSED_Z_VAR.