pub struct TextAlignMix<P>(/* private fields */);Expand description
m Text align, justify.
All properties in this mixin affects Text! nodes inside the widget where they are set.
Implementations
Sourceimpl TextAlignMix<()>
impl TextAlignMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.
Sourceimpl<P: WidgetImpl> TextAlignMix<P>
impl<P: WidgetImpl> TextAlignMix<P>
Sourcepub fn txt_align(&self, mode: impl IntoVar<Align>)
pub fn txt_align(&self, mode: impl IntoVar<Align>)
P Alignment of text inside available space.
Horizontal alignment is applied for each line independently, vertical alignment is applied for the entire text block together.
Note that the Text! widget only implements this for text inside each instance in isolation, multiple
text instances in an inline row will not all align together by the Text! layout implementation alone.
Sets the TEXT_ALIGN_VAR.
See also txt_overflow_align, used when the text overflows.
Sourceimpl<P: WidgetImpl> TextAlignMix<P>
impl<P: WidgetImpl> TextAlignMix<P>
Sourcepub fn txt_overflow_align(&self, mode: impl IntoVar<Align>)
pub fn txt_overflow_align(&self, mode: impl IntoVar<Align>)
P Alignment of text inside available space when the text overflows.
Note that the Text! widget only implements this for text inside each instance in isolation, multiple
text instances in an inline row will not all align together. Also note that txt_overflow truncation
only applies to the end of the text after it is aligned, so unless this is Align::TOP_START (default) the
start of the text maybe still be clipped after truncation.
Sets the TEXT_OVERFLOW_ALIGN_VAR.
Sourceimpl<P: WidgetImpl> TextAlignMix<P>
impl<P: WidgetImpl> TextAlignMix<P>
Sourcepub fn justify_mode(&self, mode: impl IntoVar<Justify>)
pub fn justify_mode(&self, mode: impl IntoVar<Justify>)
P Config the automatic spacing inserted between words and letters when text is aligned to fill.
Text alignment can be set to Align::FILL_X, if that is the case this config is defines how
the glyphs are spaced to fill the text block.
Sets the JUSTIFY_MODE_VAR.