TextDecorationMix

Struct TextDecorationMix 

pub struct TextDecorationMix<P>(/* private fields */);
m Text underline, overline and strikethrough lines.

All properties in this mixin affects Text! nodes inside the widget where they are set.

Implementations

Source

impl TextDecorationMix<()>

pub fn context_vars_set(set: &mut ContextValueSet)

Insert context variables used by properties in this mixin.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn underline( &self, thickness: impl IntoVar<UnderlineThickness>, style: impl IntoVar<LineStyle>, )

P Draw lines under each text line.

Sets the UNDERLINE_THICKNESS_VAR and UNDERLINE_STYLE_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn underline_color(&self, color: impl IntoVar<Rgba>)

P Custom underline color, if not set the font_color is used.

Sets the UNDERLINE_COLOR_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn underline_skip(&self, skip: impl IntoVar<UnderlineSkip>)

P Defines what segments of each text line are skipped when tracing the underline.

By default skips glyphs that intercept the underline.

Sets the UNDERLINE_SKIP_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn underline_position(&self, position: impl IntoVar<UnderlinePosition>)

P Defines what font line gets traced by the underline.

By default uses the font configuration, but it usually crosses over glyph descents causing skips on the line, you can set this UnderlinePosition::Descent to fully clear all glyph descents.

Sets the UNDERLINE_POSITION_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn overline( &self, thickness: impl IntoVar<TextLineThickness>, style: impl IntoVar<LineStyle>, )

P Draw lines above each text line.

Sets the OVERLINE_THICKNESS_VAR and OVERLINE_STYLE_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn overline_color(&self, color: impl IntoVar<Rgba>)

P Custom overline color, if not set the font_color is used.

Sets the OVERLINE_COLOR_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn strikethrough( &self, thickness: impl IntoVar<TextLineThickness>, style: impl IntoVar<LineStyle>, )

P Draw lines across each text line.

Sets the STRIKETHROUGH_THICKNESS_VAR and STRIKETHROUGH_STYLE_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn strikethrough_color(&self, color: impl IntoVar<Rgba>)

P Custom strikethrough color, if not set the font_color is used.

Sets the STRIKETHROUGH_COLOR_VAR.

Source

impl<P: WidgetImpl> TextDecorationMix<P>

pub fn ime_underline( &self, thickness: impl IntoVar<UnderlineThickness>, style: impl IntoVar<LineStyle>, )

P Style and thickness of the line drawn under the IME preview text.

Sets the IME_UNDERLINE_THICKNESS_VAR and IME_UNDERLINE_STYLE_VAR.