pub struct TextFillMix<P>(/* private fields */);Expand description
m Text color properties.
All properties in this mixin affects Text! nodes inside the widget where they are set.
Implementations
Sourceimpl TextFillMix<()>
impl TextFillMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.
Sourceimpl<P: WidgetImpl> TextFillMix<P>
impl<P: WidgetImpl> TextFillMix<P>
Sourcepub fn font_color(&self, color: impl IntoVar<Rgba>)
pub fn font_color(&self, color: impl IntoVar<Rgba>)
P Defines the color the most text glyphs are filled with.
Colored glyphs (Emoji) are not affected by this, you can use font_palette to modify
Emoji colors.
Sets the FONT_COLOR_VAR.
Sourceimpl<P: WidgetImpl> TextFillMix<P>
impl<P: WidgetImpl> TextFillMix<P>
Sourcepub fn font_palette(&self, palette: impl IntoVar<FontColorPalette>)
pub fn font_palette(&self, palette: impl IntoVar<FontColorPalette>)
P Defines the palette used to render colored glyphs (Emoji).
This property only affects Emoji from fonts using COLR v0. You can use font_color to set
the base color, and font_palette_colors to change specific colors.
Sets the FONT_PALETTE_VAR.
Sourceimpl<P: WidgetImpl> TextFillMix<P>
impl<P: WidgetImpl> TextFillMix<P>
Sourcepub fn font_palette_colors(&self, colors: impl IntoVar<Vec<(u16, Rgba)>>)
pub fn font_palette_colors(&self, colors: impl IntoVar<Vec<(u16, Rgba)>>)
P Defines custom palette colors that affect Emoji colors.
The palette is selected by font_palette and then each valid index entry in this property replaces
the selected color.
Sets the FONT_PALETTE_COLORS_VAR.