pub struct TextTransformMix<P>(/* private fields */);Expand description
m Text transform properties.
All properties in this mixin affects Text! nodes inside the widget where they are set.
Implementations
Sourceimpl TextTransformMix<()>
impl TextTransformMix<()>
Sourcepub fn context_vars_set(set: &mut ContextValueSet)
pub fn context_vars_set(set: &mut ContextValueSet)
Insert context variables used by properties in this mixin.
Sourceimpl<P: WidgetImpl> TextTransformMix<P>
impl<P: WidgetImpl> TextTransformMix<P>
Sourcepub fn white_space(&self, transform: impl IntoVar<WhiteSpace>)
pub fn white_space(&self, transform: impl IntoVar<WhiteSpace>)
P Text white space transform.
Can be used to collapse a sequence of spaces into a single one, or to ignore line-breaks.
Is WhiteSpace::Preserve by default.
This property is not applied when the text is txt_editable.
Sets the WHITE_SPACE_VAR.
Sourceimpl<P: WidgetImpl> TextTransformMix<P>
impl<P: WidgetImpl> TextTransformMix<P>
Sourcepub fn txt_transform(&self, transform: impl IntoVar<TextTransformFn>)
pub fn txt_transform(&self, transform: impl IntoVar<TextTransformFn>)
P Text transform, character replacement applied to the text before it is processed by the text widget.
This property is not applied when the text is txt_editable.
Sets the TEXT_TRANSFORM_VAR.